==> haskell-djot-0.1.1.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 djot
version:              0.1.1.3
visibility:           public
id:                   djot-0.1.1.3-C4MZNAF9EMnF2CSaxroRdk
key:                  djot-0.1.1.3-C4MZNAF9EMnF2CSaxroRdk
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  762e2957ab1e97bb8b827b4420a3c89e
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.1.3-C4MZNAF9EMnF2CSaxroRdk
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    doclayout-0.4.0.1-OeUzmBBjGb3c9PZJBHEVq mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djot-0.1.1.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 djot
version:              0.1.1.3
visibility:           public
id:                   djot-0.1.1.3-IBUDSS3pQVk9NjNvVxdnZ2
key:                  djot-0.1.1.3-IBUDSS3pQVk9NjNvVxdnZ2
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  d37788621d2f631718c0012fb305c690
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.1.3-IBUDSS3pQVk9NjNvVxdnZ2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    doclayout-0.4.0.1-FncRGvpl2Ap7XygFmE7lxE mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
